//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace IntegralUI_WinForms_Samples
{
    public partial class Form1 : Form
    {
        #region Variables
        private int[] randomInts = null;
        private int nodeCount = 0;
        #endregion

        #region Initialization
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();

            InitList();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>In this sample we are demonstrating how to expand nodes by clicking on hyperlink inside node space.</p><br></br>";
            content += "<p>There are 3 cases presented:<br></br>";
            content += "   1. Whole node is a hyperlink<br></br>";
            content += "   2. Node contains hyperlinks inside its content<br></br>";
            content += "   3. Node contains a hyperlink aligned on right side</p><br></br>";
            content += "<p>In each case you can expand or collapse nodes, except in second case where node is expanded from first hyperlink and collapsed from the second.</p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void InitList()
        {
            this.treeView1.SuspendUpdate();

            nodeCount = 0;
            randomInts = CreateRandomInts();

            CreateNode(this.treeView1.RootNode, "", 0);

            this.treeView1.ResumeUpdate();
        }

        private void CreateNode(LidorSystems.IntegralUI.Lists.TreeNode parentNode, String prefix, int level)
        {
            if (level == 5)
                return;

            int limit = randomInts[nodeCount % 99];
            if (level == 0)
                limit = 25;

            LidorSystems.IntegralUI.Lists.TreeNode node = null;
            for (int i = 1; i <= limit; i++)
            {
                node = new LidorSystems.IntegralUI.Lists.TreeNode("Node " + prefix + i.ToString());
                node.Key = node.Text;
                nodeCount++;

                CreateNode(node, prefix + i.ToString(), level + 1);

                if (node.Nodes.Count > 0)
                {
                    switch (nodeCount % 7)
                    {
                        case 2:
                            // A node with multuple hyperlinks
                            node.Content = "<div>" + node.Text + " - Multiple hyperlinks: one will <a href=\"Expand\" id=\"" + node.Key + "\" style=\"hovertextcolor:Blue\">Expand</a> and the other will <a href=\"Collapse\" id=\"" + node.Key + "\" style=\"hovertextcolor:Blue\">Collapse</a></div>";
                            break;
                        case 4:
                            // Node with a hyperlink aligned to the right side
                            node.Content = "<div><table width=\"100%\"><tr><td width=\"100%\">" + node.Text + "</td><td style=\"hovertextcolor:Red\"><a href=\"Toggle\" id=\"" + node.Key + "\">Toggle</a></td></tr></table></div>";
                            break;
                        case 1:
                        case 6:
                            // Whole node is a hyperlink
                            node.Content = "<div><a href=\"" + node.Text + "\" id=\"" + node.Key + "\" style=\"hovertextcolor:Green\">" + node.Text + " - Click to Expand and Collapse the node</a></div>";
                            break;
                    }
                }

                parentNode.Nodes.Add(node);

            }
        }

        private int[] CreateRandomInts()
        {
            int[] rand = new int[100];
            Random gen = new Random();
            for (int i = 0; i < rand.Length; i++)
                rand[i] = gen.Next(0, 5);

            return rand;
        }
        #endregion

        #region Hyperlink Events
        private void treeView1_ItemObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            // Hyperlinks in node are converted to standard LinkLabel control
            // Check whether the object within the event is of type LinkLabel
            if (e.Object is LinkLabel)
            {
                LinkLabel lLabel = (LinkLabel)e.Object;
                String action = lLabel.Links[0].LinkData.ToString();

                // Determine which node's hyperlink is clicked using the KEY carried with the event
                // If a node is found, expand or collapse it
                LidorSystems.IntegralUI.Lists.TreeNode node = this.treeView1.FindNode(e.Key, LidorSystems.IntegralUI.Lists.ListSearchCriteria.byKey);
                if (node != null)
                {
                    switch (action)
                    {
                        case "Expand":
                            node.Expand();
                            break;

                        case "Collapse":
                            node.Collapse();
                            break;

                        default:
                            node.Toggle();
                            break;
                    }
                }
            }
        }
        #endregion
    }
}